@@ -13,6 +13,13 @@
 ## You should have received a copy of the GNU General Public License
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
+## -*- texinfo -*-
+## @deftypefn{Function File} {} __pserver_exit__ ()
+##
+## Undocumented internal function.
+##
+## @end deftypefn
+
 function __pserver_exit__ (hn)
 
   ## Will be initialized and then registered as an exit function of
