@@ -13,11 +13,23 @@
 ## You should have received a copy of the GNU General Public License
 ## along with this program; If not, see <http://www.gnu.org/licenses/>.
 
-function scloseall (sockets)
+## -*- texinfo -*-
+## @deftypefn {Function File} {} scloseall (@var{connections})
+## Deprecated function, calls @code{sclose (connections)}, which should
+## be called directly.
+##
+## @seealso {sclose}
+## @end deftypefn
 
-  ## scloseall (sockets)
+function scloseall (connections)
 
-  reval ("sclose (sockets); __exit__;", sockets);
-  sclose (sockets);
+  persistent warned = false;
+  if (! warned)
+    warned = true;
+    warning ("Octave:deprecated-function",
+             "scloseall is deprecated, please use sclose directly.");
+  endif
+
+  sclose (connections);
 
 endfunction
