@@ -13,5 +13,8 @@
 ## You should have received a copy of the GNU General Public License
 ## along with this program; If not, see <http://www.gnu.org/licenses/>.
 
-## Start server for remote execution with package 'parallel'.
+## This script is here for backwards compatibility and is deprecated. It
+## just calls 'pserver', which should be called directly instead. See
+## documentation of 'pserver'.
+
 pserver
