@@ -41,7 +41,13 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 #include <stdio.h>
 
+#ifdef HAVE_MALLOC_H
 #include <malloc.h>
+#elif HAVE_SYS_MALLOC_H
+#include <sys/malloc.h>
+#else
+#error "No malloc.h present."
+#endif
 
 /*
 not necessary with current Octave
