@@ -234,19 +234,66 @@ static int check_and_write_pidfile (const char *fname, int pid)
 
 DEFUN_DLD (pserver, args, ,
            "-*- texinfo -*-\n\
-@deftypefn {Loadable Function} pserver ()\n\
-@deftypefnx {Loadable Function} pserver (@var{options})\n\
+@deftypefn {Loadable Function} {} pserver ()\n\
+@deftypefnx {Loadable Function} {} pserver (@var{options})\n\
 This function starts a server of the parallel cluster and should be called once at any server machine.\n\
-It is important to call this function in a way assuring that Octave is quit as soon as the function returns, i.e. call it e.g. like @code{octave --eval \"pserver\"} or @code{octave --eval \"pserver (struct ('fieldname', value))\"}.\n\n\
-If a directory path corresponding to the current directory of the client exists on the server machine, it will be used as the servers current directory for the respective client (multiple clients are possible). Otherwise, @code{/tmp} will be used. The Octave functions the server is supposed to call and the files it possibly has to access must be available at the server machine. This can e.g. be achieved by having the server machine mount a network file system (which is outside the scope of this package documentation).\n\n\
-The parent server process can only be terminated by sending it a signal. The pid of this process, as long as it is running, will be stored in the file @code{/tmp/.octave-<hostname>.pid}.\n\n\
-If a connection is accepted from a client, the server collects a network identifier and the names of all server machines of the network from the client. Then, connections are automatically established between all machines of the network. Data exchange will be possible between all machines (client or server) in both directions. Commands can only be sent from the client to any server.\n\n\
-The opaque variable holding the network connections, in the same order as in the corresponding variable returned by @code{pconnect}, is accessible under the variable name @code{sockets} at the server side. Do not overwrite or clear this variable. The own server machine will also be contained at some index position of this variable, but will not correspond to a real connection. See @code{pconnect} for further information.\n\n\
-@var{options}: structure of options; field @code{use_tls} is @code{true} by default (TLS with SRP authentication); if set to @code{false}, there will be no encryption or authentication. Field @code{auth_file} can be set to an alternative path to the file with authentication information (see below).\n\n\
-The client and the server must both use or both not use TLS. If TLS is switched off, different measures must be taken to protect ports 12501 and 12502 at the servers and the client against unauthorized access; e.g. by a firewall or by physical isolation of the network.\n\n\
-For using TLS, authorization data must be present at the server machine. These data can conveniently be generated by @code{parallel_generate_srp_data}; the helptext of the latter function documents the expected location of these data.\n\n\
-The SRP password will be sent over the encrypted TLS channel from the client to each server, to avoid permanently storing passwords at the server for server-to-server data connections. Due to inevitable usage of external libraries, memory with sensitive data can, however, be on the swap device even after shutdown of the application.\n\n\
-@seealso{pconnect, reval, send, recv, sclose, parallel_generate_srp_data, select_sockets}\n\
+\n\
+It is important to call this function in a way assuring that Octave is\n\
+quit as soon as the function returns, i.e. call it e.g. like\n\
+@code{octave --eval \"pserver\"} or @code{octave --eval \"pserver\n\
+(struct ('fieldname', value))\"}.\n\
+\n\
+If a directory path corresponding to the current directory of the\n\
+client exists on the server machine, it will be used as the servers\n\
+current directory for the respective client (multiple clients are\n\
+possible). Otherwise, @code{/tmp} will be used. The Octave functions\n\
+the server is supposed to call and the files it possibly has to access\n\
+must be available at the server machine. This can e.g. be achieved by\n\
+having the server machine mount a network file system (which is\n\
+outside the scope of this package documentation).\n\
+\n\
+The parent server process can only be terminated by sending it a\n\
+signal. The pid of this process, as long as it is running, will be\n\
+stored in the file @code{/tmp/.octave-<hostname>.pid}.\n\
+\n\
+If a connection is accepted from a client, the server collects a\n\
+network identifier and the names of all server machines of the network\n\
+from the client. Then, connections are automatically established\n\
+between all machines of the network. Data exchange will be possible\n\
+between all machines (client or server) in both directions. Commands\n\
+can only be sent from the client to any server.\n\
+\n\
+The opaque variable holding the network connections, in the same order\n\
+as in the corresponding variable returned by @code{pconnect}, is\n\
+accessible under the variable name @code{sockets} at the server\n\
+side. Do not overwrite or clear this variable. The own server machine\n\
+will also be contained at some index position of this variable, but\n\
+will not correspond to a real connection. See @code{pconnect} for\n\
+further information.\n\
+\n\
+@var{options}: structure of options; field @code{use_tls} is\n\
+@code{true} by default (TLS with SRP authentication); if set to\n\
+@code{false}, there will be no encryption or authentication. Field\n\
+@code{auth_file} can be set to an alternative path to the file with\n\
+authentication information (see below).\n\
+\n\
+The client and the server must both use or both not use TLS. If TLS is\n\
+switched off, different measures must be taken to protect ports 12501\n\
+and 12502 at the servers and the client against unauthorized access;\n\
+e.g. by a firewall or by physical isolation of the network.\n\
+\n\
+For using TLS, authorization data must be present at the server\n\
+machine. These data can conveniently be generated by\n\
+@code{parallel_generate_srp_data}; the helptext of the latter function\n\
+documents the expected location of these data.\n\
+\n\
+The SRP password will be sent over the encrypted TLS channel from the\n\
+client to each server, to avoid permanently storing passwords at the\n\
+server for server-to-server data connections. Due to inevitable usage\n\
+of external libraries, memory with sensitive data can, however, be on\n\
+the swap device even after shutdown of the application.\n\
+\n\
+@seealso{pconnect, reval, psend, precv, sclose, parallel_generate_srp_data, select_sockets}\n\
 @end deftypefn")
 {
   // Contrary to what is done in the client side function connect.cc,
@@ -644,13 +691,13 @@ The SRP password will be sent over the encrypted TLS channel from the client to
               dsprintf ("%i: will generate gnutls streambuf\n", server_no);
               cmd_strb = new octave_parallel_gnutls_streambuf
                 (asock, scred, true);
+              __scg.__release ();
               dsprintf ("%i: generated gnutls streambuf\n", server_no);
             }
           else
 #endif
             cmd_strb = new octave_parallel_socket_streambuf (asock);
           octave_parallel_stream cmd_str (cmd_strb);
-          __scg.__release ();
           if (! cmd_str.good ())
             {
               error ("could not create command stream");
