@@ -48,10 +48,20 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 DEFUN_DLD (reval, args, ,
            "-*- texinfo -*-\n\
-@deftypefn {Loadable Function} reval (@var{commands}, @var{connections})\n\
+@deftypefn {Loadable Function} {} reval (@var{commands}, @var{connections})\n\
 Evaluate @var{commands} at all remote hosts specified by @var{connections}.\n\
-This function can only be successfully called at the client machine. @var{commands} must be a string containing Octave commands suitable for execution with Octaves @code{eval()} function. See @code{pconnect} for a description of the @var{connections} variable. @var{connections} can contain all connections of the network, a subset of them, or a single connection. The local machine (client), if contained in @var{connections}, is ignored. @var{commands} is executed in the same way at each specified machine.\n\n\
-@seealso{pconnect, pserver, send, recv, sclose, parallel_generate_srp_data, select_sockets}\n\
+\n\
+This function can only be successfully called at the client\n\
+machine. @var{commands} must be a string containing Octave commands\n\
+suitable for execution with Octaves @code{eval()} function. See\n\
+@code{pconnect} for a description of the @var{connections}\n\
+variable. @var{connections} can contain all connections of the\n\
+network, a subset of them, or a single connection. The local machine\n\
+(client), if contained in @var{connections}, is\n\
+ignored. @var{commands} is executed in the same way at each specified\n\
+machine.\n\
+\n\
+@seealso{pconnect, pserver, psend, precv, sclose, parallel_generate_srp_data, select_sockets}\n\
 @end deftypefn")
 {
   std::string fname ("reval");
