@@ -48,10 +48,14 @@ along with this program; If not, see <http://www.gnu.org/licenses/>.
 
 DEFUN_DLD (sclose, args, ,
            "-*- texinfo -*-\n\
-@deftypefn {Loadable Function} sclose (@var{connections})\n\
+@deftypefn {Loadable Function} {} sclose (@var{connections})\n\
 Close the parallel cluster network to which @var{connections} belongs.\n\
-See @code{pconnect} for a description of the @var{connections} variable. All connections of the network are closed, even if @var{connections} contains only a subnet or a single connection.\n\n\
-@seealso{pconnect, pserver, reval, send, recv, parallel_generate_srp_data, select_sockets}\n\
+\n\
+See @code{pconnect} for a description of the @var{connections}\n\
+variable. All connections of the network are closed, even if\n\
+@var{connections} contains only a subnet or a single connection.\n\
+\n\
+@seealso{pconnect, pserver, reval, psend, precv, parallel_generate_srp_data, select_sockets}\n\
 @end deftypefn")
 {
   std::string fname ("sclose");
