@@ -30,6 +30,7 @@ DEFUN_DLD (select, args, nargout,
   "-*- texinfo -*-\n\
 @deftypefn {Loadable Function} {[@var{n}, @var{ridx}, @var{widx}, @var{eidx}] =} select (@var{read_fids}, @var{write_fids}, @var{except_fids}, @var{timeout}[, @var{nfds}])\n\
 Calls Unix @code{select}, see the respective manual.\n\
+\n\
 The following interface was chosen:\n\
 @var{read_fids}, @var{write_fids}, @var{except_fids}: vectors of stream-ids.\n\
 @var{timeout}: seconds, negative for infinite.\n\
@@ -110,7 +111,7 @@ Return values are:\n\
 
         fd_set rfds, wfds, efds;
         FD_ZERO (&rfds); FD_ZERO (&wfds); FD_ZERO (&efds);
-        for (i = 0; i < read_fids.length (); i++) {
+        for (i = 0; i < read_fids.numel (); i++) {
                 fid = lrint (read_fids(i));
                 fd = octave_stream_list::lookup (fid, "select") . 
                         file_number ();
@@ -124,7 +125,7 @@ Return values are:\n\
                 }
                 FD_SET (fid, &rfds);
         }
-        for (i = 0; i < write_fids.length (); i++) {
+        for (i = 0; i < write_fids.numel (); i++) {
                 fid = lrint (write_fids(i));
                 fd = octave_stream_list::lookup (fid, "select") . 
                         file_number ();
@@ -138,7 +139,7 @@ Return values are:\n\
                 }
                 FD_SET (fid, &wfds);
         }
-        for (i = 0; i < except_fids.length (); i++) {
+        for (i = 0; i < except_fids.numel (); i++) {
                 fid = lrint (except_fids(i));
                 fd = octave_stream_list::lookup (fid, "select") . 
                         file_number ();
@@ -173,11 +174,11 @@ Return values are:\n\
                 return retval;
         }
         if (nargout > 3) {
-                for (i = 0, act = 0; i < except_fids.length (); i++)
+                for (i = 0, act = 0; i < except_fids.numel (); i++)
                         if (FD_ISSET (lrint (except_fids(i)), &efds)) act++;
                 RowVector eidx = RowVector (act);
                 for (i = 0, fvec = eidx.fortran_vec ();
-                     i < except_fids.length (); i++)
+                     i < except_fids.numel (); i++)
                         if (FD_ISSET (lrint (except_fids(i)), &efds)) {
                                 *fvec = double (i + 1);
                                 fvec++;
@@ -185,11 +186,11 @@ Return values are:\n\
                 retval(3) = eidx;
         }
         if (nargout > 2) {
-                for (i = 0, act = 0; i < write_fids.length (); i++)
+                for (i = 0, act = 0; i < write_fids.numel (); i++)
                         if (FD_ISSET (lrint (write_fids(i)), &wfds)) act++;
                 RowVector widx = RowVector (act);
                 for (i = 0, fvec = widx.fortran_vec ();
-                     i < write_fids.length (); i++)
+                     i < write_fids.numel (); i++)
                         if (FD_ISSET (lrint (write_fids(i)), &wfds)) {
                                 *fvec = double (i + 1);
                                 fvec++;
@@ -197,11 +198,11 @@ Return values are:\n\
                 retval(2) = widx;
         }
         if (nargout > 1) {
-                for (i = 0, act = 0; i < read_fids.length (); i++)
+                for (i = 0, act = 0; i < read_fids.numel (); i++)
                         if (FD_ISSET (lrint (read_fids(i)), &rfds)) act++;
                 RowVector ridx = RowVector (act);
                 for (i = 0, fvec = ridx.fortran_vec ();
-                     i < read_fids.length (); i++)
+                     i < read_fids.numel (); i++)
                         if (FD_ISSET (lrint (read_fids(i)), &rfds)) {
                                 *fvec = double (i + 1);
                                 fvec++;
